.. GoFigr Client Library documentation master file, created by
   sphinx-quickstart on Thu Mar 30 11:36:24 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. figure:: images/logo_wide.png
  :alt: GoFigr.io logo


Welcome to GoFigr Client Library's documentation!
=================================================

Version: 1.3.1

.. toctree::
   :maxdepth: 4
   :caption: Quick Start Guide:

   start
   library_support
   boilerplate
   customization
   organization

.. toctree::
   :maxdepth: 4
   :caption: Tips and tricks:

   tips

.. toctree::
   :maxdepth: 4
   :caption: Module Reference:

   modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
